Version history — Cabby 0.1.4a documentation

### Navigation

- index
- modules |
- next |
- previous |
- Cabby 0.1.4a documentation »

# Version history

## cabby 0.1.3

Release date: 2015-04-08

- Workaround for libtaxii issue #186 (wrapping incorrect response in Status Message) has been added.
- Tests improved.

## cabby 0.1.2

Release date: 2015-03-31

- Issue with proxy arguments being ignored is fixed.
- Issue with poll results print in CLI referencing wrong entity is fixed.
- Wording and style fixes.

## cabby 0.1.1

Release date: 2015-03-26

- Tidying up packaging and distribution related configuration

## cabby 0.1.0

Release date: 2015-03-26

- Initial release

### Navigation

- index
- modules |
- next |
- previous |
- Cabby 0.1.4a documentation »